@@ -113,6 +113,12 @@ get_provider_features (GoaProvider *_provider)
   return GOA_PROVIDER_FEATURE_TICKETING;
 }
 
+static GIcon *
+get_provider_icon (GoaProvider *provider, GoaObject *object)
+{
+  return g_themed_icon_new_with_default_fallbacks ("dialog-password-symbolic");
+}
+
 typedef struct
 {
   GtkDialog *dialog;
@@ -1319,16 +1325,13 @@ static gboolean
 dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
                                    GCancellable  *cancellable)
 {
-  GVariant *result = NULL;
+  GVariant *result;
   char *name;
-  char *name_owner = NULL;
   GVariant *value;
-  GVariantIter *iter = NULL;
-  gboolean ret = FALSE;
+  GVariantIter *iter;
 
-  name_owner = g_dbus_proxy_get_name_owner (proxy);
   result = g_dbus_connection_call_sync (g_dbus_proxy_get_connection (proxy),
-                                        name_owner,
+                                        g_dbus_proxy_get_name_owner (proxy),
                                         g_dbus_proxy_get_object_path (proxy),
                                         "org.freedesktop.DBus.Properties",
                                         "GetAll",
@@ -1339,7 +1342,7 @@ dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
                                         cancellable,
                                         NULL);
   if (result == NULL)
-    goto out;
+    return FALSE;
 
   g_variant_get (result, "(a{sv})", &iter);
   while (g_variant_iter_next (iter, "{sv}", &name, &value))
@@ -1349,14 +1352,8 @@ dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
       g_free (name);
       g_variant_unref (value);
     }
-
-  ret = TRUE;
-
- out:
-  g_clear_pointer (&iter, (GDestroyNotify) g_variant_iter_free);
-  g_clear_pointer (&result, (GDestroyNotify) g_variant_unref);
-  g_free (name_owner);
-  return ret;
+  g_variant_iter_free (iter);
+  return TRUE;
 }
 
 static gboolean
@@ -1573,7 +1570,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
 {
   GcrSecretExchange  *secret_exchange;
   char               *secret_key;
-  char               *return_key = NULL;
+  char               *return_key;
   char               *concealed_secret;
   char               *identity_object_path = NULL;
   gboolean            keys_exchanged;
@@ -1627,7 +1624,6 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
   g_mutex_unlock (&identity_manager_mutex);
 
  out:
-  g_free (return_key);
   g_object_unref (secret_exchange);
   return identity_object_path;
 }
@@ -1762,6 +1758,7 @@ goa_kerberos_provider_class_init (GoaKerberosProviderClass *kerberos_class)
   provider_class->get_provider_name          = get_provider_name;
   provider_class->get_provider_group         = get_provider_group;
   provider_class->get_provider_features      = get_provider_features;
+  provider_class->get_provider_icon          = get_provider_icon;
   provider_class->build_object               = build_object;
   provider_class->add_account                = add_account;
   provider_class->refresh_account            = refresh_account;
