@@ -657,15 +657,11 @@ on_web_view_decide_policy (WebKitWebView            *web_view,
                            WebKitPolicyDecisionType  decision_type,
                            gpointer                  user_data)
 {
-  GHashTable *key_value_pairs;
   IdentifyData *data = user_data;
-  SoupURI *uri;
   WebKitNavigationAction *action;
   WebKitURIRequest *request;
-  const gchar *query;
   const gchar *redirect_uri;
   const gchar *requested_uri;
-  gint response_id = GTK_RESPONSE_NONE;
 
   if (decision_type != WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION)
     return FALSE;
@@ -676,42 +672,28 @@ on_web_view_decide_policy (WebKitWebView            *web_view,
   request = webkit_navigation_action_get_request (action);
   requested_uri = webkit_uri_request_get_uri (request);
   redirect_uri = goa_oauth_provider_get_callback_uri (data->provider);
-
-  if (!g_str_has_prefix (requested_uri, redirect_uri))
-    goto default_behaviour;
-
-  uri = soup_uri_new (requested_uri);
-  query = soup_uri_get_query (uri);
-
-  if (query != NULL)
+  if (g_str_has_prefix (requested_uri, redirect_uri))
     {
-      key_value_pairs = soup_form_decode (query);
+      SoupURI *uri;
+      GHashTable *key_value_pairs;
 
+      uri = soup_uri_new (requested_uri);
+      key_value_pairs = soup_form_decode (uri->query);
+
+      /* TODO: error handling? */
       data->oauth_verifier = g_strdup (g_hash_table_lookup (key_value_pairs, "oauth_verifier"));
       if (data->oauth_verifier != NULL)
-        response_id = GTK_RESPONSE_OK;
-
+        {
+          gtk_dialog_response (data->dialog, GTK_RESPONSE_OK);
+        }
       g_hash_table_unref (key_value_pairs);
+      webkit_policy_decision_ignore (decision);
+      return TRUE; /* ignore the request */
+    }
+  else
+    {
+      return FALSE; /* make default behavior apply */
     }
-
-  if (data->oauth_verifier != NULL)
-    goto ignore_request;
-
-  /* TODO: The only OAuth1 provider is Flickr. It doesn't send any
-   * error code and only redirects to the URI specified in the Flickr
-   * App Garden. Re-evaluate when the situation changes.
-   */
-  response_id = GTK_RESPONSE_CANCEL;
-  goto ignore_request;
-
- ignore_request:
-  g_assert (response_id != GTK_RESPONSE_NONE);
-  gtk_dialog_response (data->dialog, response_id);
-  webkit_policy_decision_ignore (decision);
-  return TRUE;
-
- default_behaviour:
-  return FALSE;
 }
 
 static void
@@ -796,8 +778,6 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   goa_utils_set_dialog_title (GOA_PROVIDER (provider), dialog, add_account);
 
   grid = gtk_grid_new ();
-  gtk_container_set_border_width (GTK_CONTAINER (grid), 5);
-  gtk_widget_set_margin_bottom (grid, 6);
   gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
   gtk_grid_set_row_spacing (GTK_GRID (grid), 12);
   gtk_container_add (GTK_CONTAINER (vbox), grid);
